@@ -1,7 +1,7 @@
 from django.contrib.contenttypes.models import ContentType
 from django.test import TestCase
 from django_dynamic_fixture import G, N
-from entity.models import Entity, EntityRelationship
+from entity.models import Entity, EntityRelationship, EntityKind
 from mock import patch
 
 from entity_subscription.models import Medium, Source, Subscription, Unsubscribe
@@ -56,32 +56,32 @@ class SubscriptionManagerMediumsSubscribedIndividualTest(TestCase):
 
     def test_individual_subscription(self):
         entity_1 = G(Entity)
-        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_type=None)
+        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_kind=None)
         mediums = Subscription.objects._mediums_subscribed_individual(source=self.source_1, entity=entity_1)
         expected_medium = self.medium_1
         self.assertEqual(mediums.first(), expected_medium)
 
     def test_group_subscription(self):
-        ct = G(ContentType)
+        ek = G(EntityKind)
         super_e = G(Entity)
-        sub_e = G(Entity, entity_type=ct)
+        sub_e = G(Entity, entity_kind=ek)
         G(EntityRelationship, super_entity=super_e, sub_entity=sub_e)
-        G(Subscription, entity=super_e, medium=self.medium_1, source=self.source_1, subentity_type=ct)
+        G(Subscription, entity=super_e, medium=self.medium_1, source=self.source_1, subentity_kind=ek)
         mediums = Subscription.objects._mediums_subscribed_individual(source=self.source_1, entity=sub_e)
         expected_medium = self.medium_1
         self.assertEqual(mediums.first(), expected_medium)
 
     def test_multiple_mediums(self):
         entity_1 = G(Entity)
-        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_type=None)
-        G(Subscription, entity=entity_1, medium=self.medium_2, source=self.source_1, subentity_type=None)
+        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_kind=None)
+        G(Subscription, entity=entity_1, medium=self.medium_2, source=self.source_1, subentity_kind=None)
         mediums = Subscription.objects._mediums_subscribed_individual(source=self.source_1, entity=entity_1)
         self.assertEqual(mediums.count(), 2)
 
     def test_unsubscribed(self):
         entity_1 = G(Entity)
-        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_type=None)
-        G(Subscription, entity=entity_1, medium=self.medium_2, source=self.source_1, subentity_type=None)
+        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_kind=None)
+        G(Subscription, entity=entity_1, medium=self.medium_2, source=self.source_1, subentity_kind=None)
         G(Unsubscribe, entity=entity_1, medium=self.medium_1, source=self.source_1)
         mediums = Subscription.objects._mediums_subscribed_individual(source=self.source_1, entity=entity_1)
         self.assertEqual(mediums.count(), 1)
@@ -89,15 +89,15 @@ class SubscriptionManagerMediumsSubscribedIndividualTest(TestCase):
 
     def test_filters_by_source(self):
         entity_1 = G(Entity)
-        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_type=None)
-        G(Subscription, entity=entity_1, medium=self.medium_2, source=self.source_2, subentity_type=None)
+        G(Subscription, entity=entity_1, medium=self.medium_1, source=self.source_1, subentity_kind=None)
+        G(Subscription, entity=entity_1, medium=self.medium_2, source=self.source_2, subentity_kind=None)
         mediums = Subscription.objects._mediums_subscribed_individual(source=self.source_1, entity=entity_1)
         self.assertEqual(mediums.count(), 1)
 
 
 class SubscriptionManagerMediumsSubscribedGroup(TestCase):
     def setUp(self):
-        self.ct = G(ContentType)
+        self.ek = G(EntityKind)
         self.source_1 = G(Source)
         self.source_2 = G(Source)
         self.medium_1 = G(Medium)
@@ -106,11 +106,11 @@ class SubscriptionManagerMediumsSubscribedGroup(TestCase):
     def test_one_subscription_matches_across_supers(self):
         super_1 = G(Entity)
         super_2 = G(Entity)
-        sub = G(Entity, entity_type=self.ct)
+        sub = G(Entity, entity_kind=self.ek)
         G(EntityRelationship, super_entity=super_1, sub_entity=sub)
         G(EntityRelationship, super_entity=super_2, sub_entity=sub)
-        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_type=self.ct)
-        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_2, self.ct)
+        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek)
+        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_2, self.ek)
         self.assertEqual(mediums.count(), 1)
         self.assertEqual(mediums.first(), self.medium_1)
 
@@ -118,24 +118,24 @@ class SubscriptionManagerMediumsSubscribedGroup(TestCase):
         super_1 = G(Entity)
         super_2 = G(Entity)
         super_3 = G(Entity)
-        sub = G(Entity, entity_type=self.ct)
+        sub = G(Entity, entity_kind=self.ek)
         G(EntityRelationship, super_entity=super_1, sub_entity=sub)
         G(EntityRelationship, super_entity=super_2, sub_entity=sub)
         G(EntityRelationship, super_entity=super_3, sub_entity=sub)
-        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_type=self.ct)
-        G(Subscription, entity=super_2, medium=self.medium_2, source=self.source_1, subentity_type=self.ct)
-        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_3, self.ct)
+        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek)
+        G(Subscription, entity=super_2, medium=self.medium_2, source=self.source_1, subentity_kind=self.ek)
+        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_3, self.ek)
         self.assertEqual(mediums.count(), 2)
 
     def test_filters_by_source(self):
         super_1 = G(Entity)
         super_2 = G(Entity)
-        sub = G(Entity, entity_type=self.ct)
+        sub = G(Entity, entity_kind=self.ek)
         G(EntityRelationship, super_entity=super_1, sub_entity=sub)
         G(EntityRelationship, super_entity=super_2, sub_entity=sub)
-        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_type=self.ct)
-        G(Subscription, entity=super_1, medium=self.medium_2, source=self.source_2, subentity_type=self.ct)
-        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_2, self.ct)
+        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek)
+        G(Subscription, entity=super_1, medium=self.medium_2, source=self.source_2, subentity_kind=self.ek)
+        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_2, self.ek)
         self.assertEqual(mediums.count(), 1)
         self.assertEqual(mediums.first(), self.medium_1)
 
@@ -143,57 +143,57 @@ class SubscriptionManagerMediumsSubscribedGroup(TestCase):
         super_1 = G(Entity)
         super_2 = G(Entity)
         super_3 = G(Entity)
-        sub = G(Entity, entity_type=self.ct)
+        sub = G(Entity, entity_kind=self.ek)
         G(EntityRelationship, super_entity=super_1, sub_entity=sub)
         G(EntityRelationship, super_entity=super_3, sub_entity=sub)
-        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_type=self.ct)
-        G(Subscription, entity=super_2, medium=self.medium_2, source=self.source_1, subentity_type=self.ct)
-        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_3, self.ct)
+        G(Subscription, entity=super_1, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek)
+        G(Subscription, entity=super_2, medium=self.medium_2, source=self.source_1, subentity_kind=self.ek)
+        mediums = Subscription.objects._mediums_subscribed_group(self.source_1, super_3, self.ek)
         self.assertEqual(mediums.count(), 1)
         self.assertEqual(mediums.first(), self.medium_1)
 
 
 class SubscriptionManagerIsSubScribedIndividualTest(TestCase):
     def setUp(self):
-        self.ct = G(ContentType)
+        self.ek = G(EntityKind)
         self.medium_1 = G(Medium)
         self.medium_2 = G(Medium)
         self.source_1 = G(Source)
         self.source_2 = G(Source)
-        self.entity_1 = G(Entity, entity_type=self.ct)
+        self.entity_1 = G(Entity, entity_kind=self.ek)
         self.entity_2 = G(Entity)
         G(EntityRelationship, sub_entity=self.entity_1, super_entity=self.entity_2)
 
     def test_is_subscribed_direct_subscription(self):
-        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_1, subentity_type=None)
+        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_1, subentity_kind=None)
         is_subscribed = Subscription.objects._is_subscribed_individual(
             self.source_1, self.medium_1, self.entity_1
         )
         self.assertTrue(is_subscribed)
 
     def test_is_subscribed_group_subscription(self):
-        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_type=self.ct)
+        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek)
         is_subscribed = Subscription.objects._is_subscribed_individual(
             self.source_1, self.medium_1, self.entity_1
         )
         self.assertTrue(is_subscribed)
 
     def test_filters_source(self):
-        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_2, subentity_type=None)
+        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_2, subentity_kind=None)
         is_subscribed = Subscription.objects._is_subscribed_individual(
             self.source_1, self.medium_1, self.entity_1
         )
         self.assertFalse(is_subscribed)
 
     def test_filters_medium(self):
-        G(Subscription, entity=self.entity_1, medium=self.medium_2, source=self.source_1, subentity_type=None)
+        G(Subscription, entity=self.entity_1, medium=self.medium_2, source=self.source_1, subentity_kind=None)
         is_subscribed = Subscription.objects._is_subscribed_individual(
             self.source_1, self.medium_1, self.entity_1
         )
         self.assertFalse(is_subscribed)
 
     def test_super_entity_means_not_subscribed(self):
-        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_1, subentity_type=self.ct)
+        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek)
         is_subscribed = Subscription.objects._is_subscribed_individual(
             self.source_1, self.medium_1, self.entity_1
         )
@@ -206,7 +206,7 @@ class SubscriptionManagerIsSubScribedIndividualTest(TestCase):
         self.assertFalse(is_subscribed)
 
     def test_unsubscribed(self):
-        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_1, subentity_type=None)
+        G(Subscription, entity=self.entity_1, medium=self.medium_1, source=self.source_1, subentity_kind=None)
         G(Unsubscribe, entity=self.entity_1, medium=self.medium_1, source=self.source_1)
         is_subscribed = Subscription.objects._is_subscribed_individual(
             self.source_1, self.medium_1, self.entity_1
@@ -216,62 +216,62 @@ class SubscriptionManagerIsSubScribedIndividualTest(TestCase):
 
 class SubscriptionManagerIsSubscribedGroupTest(TestCase):
     def setUp(self):
-        self.ct_1 = G(ContentType)
-        self.ct_2 = G(ContentType)
+        self.ek_1 = G(EntityKind)
+        self.ek_2 = G(EntityKind)
         self.medium_1 = G(Medium)
         self.medium_2 = G(Medium)
         self.source_1 = G(Source)
         self.source_2 = G(Source)
-        self.entity_1 = G(Entity, entity_type=self.ct_1)    # sub
+        self.entity_1 = G(Entity, entity_kind=self.ek_1)    # sub
         self.entity_2 = G(Entity)                           # super
         self.entity_3 = G(Entity)                           # super
-        self.entity_4 = G(Entity, entity_type=self.ct_2)    # sub
+        self.entity_4 = G(Entity, entity_kind=self.ek_2)    # sub
         G(EntityRelationship, sub_entity=self.entity_1, super_entity=self.entity_2)
         G(EntityRelationship, sub_entity=self.entity_1, super_entity=self.entity_3)
         G(EntityRelationship, sub_entity=self.entity_4, super_entity=self.entity_2)
         G(EntityRelationship, sub_entity=self.entity_4, super_entity=self.entity_3)
 
     def test_one_subscription_matches_across_supers(self):
-        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_type=self.ct_1)
+        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek_1)
         is_subscribed = Subscription.objects._is_subscribed_group(
-            source=self.source_1, medium=self.medium_1, entity=self.entity_3, subentity_type=self.ct_1
+            source=self.source_1, medium=self.medium_1, entity=self.entity_3, subentity_kind=self.ek_1
         )
         self.assertTrue(is_subscribed)
 
     def test_filters_source(self):
-        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_type=self.ct_1)
+        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek_1)
         is_subscribed = Subscription.objects._is_subscribed_group(
-            source=self.source_2, medium=self.medium_1, entity=self.entity_3, subentity_type=self.ct_1
+            source=self.source_2, medium=self.medium_1, entity=self.entity_3, subentity_kind=self.ek_1
         )
         self.assertFalse(is_subscribed)
 
     def test_filters_medium(self):
-        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_type=self.ct_1)
+        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek_1)
         is_subscribed = Subscription.objects._is_subscribed_group(
-            source=self.source_1, medium=self.medium_2, entity=self.entity_3, subentity_type=self.ct_1
+            source=self.source_1, medium=self.medium_2, entity=self.entity_3, subentity_kind=self.ek_1
         )
         self.assertFalse(is_subscribed)
 
-    def test_filters_subentity_type(self):
-        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_type=self.ct_1)
+    def test_filters_subentity_kind(self):
+        G(Subscription, entity=self.entity_2, medium=self.medium_1, source=self.source_1, subentity_kind=self.ek_1)
         is_subscribed = Subscription.objects._is_subscribed_group(
-            source=self.source_1, medium=self.medium_1, entity=self.entity_3, subentity_type=self.ct_2
+            source=self.source_1, medium=self.medium_1, entity=self.entity_3, subentity_kind=self.ek_2
         )
         self.assertFalse(is_subscribed)
 
 
 class SubscriptionFilterNotSubscribedTest(TestCase):
     def setUp(self):
-        self.super_ct = G(ContentType)
-        self.sub_ct = G(ContentType)
-        self.super_e1 = G(Entity, entity_type=self.super_ct)
-        self.super_e2 = G(Entity, entity_type=self.super_ct)
-        self.sub_e1 = G(Entity, entity_type=self.sub_ct)
-        self.sub_e2 = G(Entity, entity_type=self.sub_ct)
-        self.sub_e3 = G(Entity, entity_type=self.sub_ct)
-        self.sub_e4 = G(Entity, entity_type=self.sub_ct)
-        self.ind_e1 = G(Entity, entity_type=self.sub_ct)
-        self.ind_e2 = G(Entity, entity_type=self.sub_ct)
+        self.super_ek = G(EntityKind)
+        self.sub_ek = G(EntityKind)
+        self.super_e1 = G(Entity, entity_kind=self.super_ek)
+        self.super_e2 = G(Entity, entity_kind=self.super_ek)
+        self.sub_e1 = G(Entity, entity_kind=self.sub_ek)
+        self.sub_e2 = G(Entity, entity_kind=self.sub_ek)
+        self.sub_e3 = G(Entity, entity_kind=self.sub_ek)
+        self.sub_e4 = G(Entity, entity_kind=self.sub_ek)
+        self.ind_e1 = G(Entity, entity_kind=self.sub_ek)
+        self.ind_e2 = G(Entity, entity_kind=self.sub_ek)
         self.medium = G(Medium)
         self.source = G(Source)
         G(EntityRelationship, sub_entity=self.sub_e1, super_entity=self.super_e1)
@@ -280,16 +280,16 @@ class SubscriptionFilterNotSubscribedTest(TestCase):
         G(EntityRelationship, sub_entity=self.sub_e4, super_entity=self.super_e2)
 
     def test_group_and_individual_subscription(self):
-        G(Subscription, entity=self.ind_e1, source=self.source, medium=self.medium, subentity_type=None)
-        G(Subscription, entity=self.super_e1, source=self.source, medium=self.medium, subentity_type=self.sub_ct)
+        G(Subscription, entity=self.ind_e1, source=self.source, medium=self.medium, subentity_kind=None)
+        G(Subscription, entity=self.super_e1, source=self.source, medium=self.medium, subentity_kind=self.sub_ek)
         entities = [self.sub_e1, self.sub_e3, self.ind_e1, self.ind_e2]
         filtered_entities = Subscription.objects.filter_not_subscribed(self.source, self.medium, entities)
         expected_entity_ids = [self.sub_e1.id, self.ind_e1.id]
         self.assertEqual(set(filtered_entities.values_list('id', flat=True)), set(expected_entity_ids))
 
     def test_unsubscribe_filtered_out(self):
-        G(Subscription, entity=self.ind_e1, source=self.source, medium=self.medium, subentity_type=None)
-        G(Subscription, entity=self.super_e1, source=self.source, medium=self.medium, subentity_type=self.sub_ct)
+        G(Subscription, entity=self.ind_e1, source=self.source, medium=self.medium, subentity_kind=None)
+        G(Subscription, entity=self.super_e1, source=self.source, medium=self.medium, subentity_kind=self.sub_ek)
         G(Unsubscribe, entity=self.sub_e1, source=self.source, medium=self.medium)
         entities = [self.sub_e1, self.sub_e2, self.sub_e3, self.ind_e1, self.ind_e2]
         filtered_entities = Subscription.objects.filter_not_subscribed(self.source, self.medium, entities)
@@ -297,13 +297,13 @@ class SubscriptionFilterNotSubscribedTest(TestCase):
         self.assertEqual(set(filtered_entities.values_list('id', flat=True)), set(expected_entity_ids))
 
     def test_entities_not_passed_in_filtered(self):
-        G(Subscription, entity=self.ind_e1, source=self.source, medium=self.medium, subentity_type=None)
-        G(Subscription, entity=self.super_e1, source=self.source, medium=self.medium, subentity_type=self.sub_ct)
-        entities = list(self.super_e1.get_sub_entities().is_any_type(self.sub_ct))
+        G(Subscription, entity=self.ind_e1, source=self.source, medium=self.medium, subentity_kind=None)
+        G(Subscription, entity=self.super_e1, source=self.source, medium=self.medium, subentity_kind=self.sub_ek)
+        entities = [se for se in self.super_e1.get_sub_entities() if se.entity_kind == self.sub_ek]
         filtered_entities = Subscription.objects.filter_not_subscribed(self.source, self.medium, entities)
         self.assertEqual(set(filtered_entities), set(entities))
 
-    def test_different_entity_types_raises_error(self):
+    def test_different_entity_kinds_raises_error(self):
         entities = [self.sub_e1, self.super_e1]
         with self.assertRaises(ValueError):
             Subscription.objects.filter_not_subscribed(self.source, self.medium, entities)
@@ -324,9 +324,9 @@ class UnsubscribeManagerIsUnsubscribed(TestCase):
 
 class NumberOfQueriesTests(TestCase):
     def test_query_count(self):
-        ct = G(ContentType)
-        e0 = G(Entity, entity_type=ct)   # sub
-        e1 = G(Entity, entity_type=ct)   # sub
+        ek = G(EntityKind)
+        e0 = G(Entity, entity_kind=ek)   # sub
+        e1 = G(Entity, entity_kind=ek)   # sub
         e2 = G(Entity)                   # super
         e3 = G(Entity)                   # super
         e4 = G(Entity)                   # super
@@ -334,43 +334,43 @@ class NumberOfQueriesTests(TestCase):
         e6 = G(Entity)                   # super
         m1, m2, m3, m4, m5 = G(Medium), G(Medium), G(Medium), G(Medium), G(Medium)
         s1, s2 = G(Source), G(Source)
-        G(EntityRelationship, sub_entity=e1, super_entity=e2, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e1, super_entity=e3, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e1, super_entity=e4, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e1, super_entity=e5, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e1, super_entity=e6, subentity_type=ct)
+        G(EntityRelationship, sub_entity=e1, super_entity=e2, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e1, super_entity=e3, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e1, super_entity=e4, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e1, super_entity=e5, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e1, super_entity=e6, subentity_kind=ek)
 
-        G(EntityRelationship, sub_entity=e0, super_entity=e2, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e0, super_entity=e3, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e0, super_entity=e4, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e0, super_entity=e5, subentity_type=ct)
-        G(EntityRelationship, sub_entity=e0, super_entity=e6, subentity_type=ct)
+        G(EntityRelationship, sub_entity=e0, super_entity=e2, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e0, super_entity=e3, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e0, super_entity=e4, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e0, super_entity=e5, subentity_kind=ek)
+        G(EntityRelationship, sub_entity=e0, super_entity=e6, subentity_kind=ek)
 
-        G(Subscription, entity=e2, subentity_type=ct, source=s1, medium=m1)
-        G(Subscription, entity=e3, subentity_type=ct, source=s1, medium=m2)
-        G(Subscription, entity=e4, subentity_type=ct, source=s1, medium=m3)
-        G(Subscription, entity=e5, subentity_type=ct, source=s1, medium=m4)
-        G(Subscription, entity=e6, subentity_type=ct, source=s1, medium=m5)
+        G(Subscription, entity=e2, subentity_kind=ek, source=s1, medium=m1)
+        G(Subscription, entity=e3, subentity_kind=ek, source=s1, medium=m2)
+        G(Subscription, entity=e4, subentity_kind=ek, source=s1, medium=m3)
+        G(Subscription, entity=e5, subentity_kind=ek, source=s1, medium=m4)
+        G(Subscription, entity=e6, subentity_kind=ek, source=s1, medium=m5)
 
-        G(Subscription, entity=e2, subentity_type=ct, source=s2, medium=m1)
-        G(Subscription, entity=e3, subentity_type=ct, source=s2, medium=m2)
-        G(Subscription, entity=e4, subentity_type=ct, source=s2, medium=m3)
-        G(Subscription, entity=e5, subentity_type=ct, source=s2, medium=m4)
-        G(Subscription, entity=e6, subentity_type=ct, source=s2, medium=m5)
+        G(Subscription, entity=e2, subentity_kind=ek, source=s2, medium=m1)
+        G(Subscription, entity=e3, subentity_kind=ek, source=s2, medium=m2)
+        G(Subscription, entity=e4, subentity_kind=ek, source=s2, medium=m3)
+        G(Subscription, entity=e5, subentity_kind=ek, source=s2, medium=m4)
+        G(Subscription, entity=e6, subentity_kind=ek, source=s2, medium=m5)
 
         with self.assertNumQueries(1):
             mediums = Subscription.objects._mediums_subscribed_individual(source=s1, entity=e1)
             list(mediums)
 
         with self.assertNumQueries(1):
-            mediums = Subscription.objects._mediums_subscribed_group(source=s1, entity=e6, subentity_type=ct)
+            mediums = Subscription.objects._mediums_subscribed_group(source=s1, entity=e6, subentity_kind=ek)
             list(mediums)
 
         with self.assertNumQueries(2):
             Subscription.objects._is_subscribed_individual(source=s1, medium=m1, entity=e1)
 
         with self.assertNumQueries(1):
-            Subscription.objects._is_subscribed_group(source=s1, medium=m1, entity=e6, subentity_type=ct)
+            Subscription.objects._is_subscribed_group(source=s1, medium=m1, entity=e6, subentity_kind=ek)
 
         with self.assertNumQueries(1):
             entities = [e0, e1]
@@ -380,7 +380,7 @@ class NumberOfQueriesTests(TestCase):
 class UnicodeMethodTests(TestCase):
     def setUp(self):
         self.entity = G(
-            Entity, entity_meta={'name': 'Entity Test'}
+            Entity, entity_meta={'name': 'Entity Test'}, display_name='Entity Test'
         )
         self.medium = G(
             Medium, name='test', display_name='Test', description='A test medium.'
